@@ -2,9 +2,11 @@
     This module implements the Report class.
 """
 
+from pathlib import Path
 from tempfile import NamedTemporaryFile
-from bokeh.models import LayoutDOM
+
 from bokeh.io import save
+from bokeh.models import LayoutDOM
 from bokeh.resources import CDN
 
 
@@ -25,9 +27,17 @@ class Report:
         save(self.to_render, filename=filename, resources=CDN, title="Report")
 
     def _repr_html_(self) -> str:
-        with NamedTemporaryFile(suffix=".html") as f:
-            save(self.to_render, filename=f.name, resources=CDN, title="Report")
-            output_html = f.read().decode("utf-8")
+        # Windows forbids us open the file twice as the result bokeh cannot
+        # write to the opened temporary file.
+        with NamedTemporaryFile(suffix=".html", delete=False) as tmpf:
+            pass
+
+        save(self.to_render, filename=tmpf.name, resources=CDN, title="Report")
+        with open(tmpf.name, "r") as f:
+            output_html = f.read()
+
+        # Delete the temporary file
+        Path(tmpf.name).unlink()
 
         # embed into report template created by us here
         return output_html
